# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## 1.0.1 - 2024-04-23

### Added

- This changelog file.

### Fixed

- Added missing `HttpRequest` import.

## 1.0.0 - 2023-12-20

### Added

- Initial release.
